@@ -1,5 +1,5 @@
 /*
- * $Id: shoutcast.c,v 1.141 2004/03/28 21:52:14 jylefort Exp $
+ * $Id: shoutcast.c,v 1.141.2.1 2004/05/11 10:54:34 jylefort Exp $
  *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -32,10 +32,10 @@
  */
 
 #include "config.h"
-#include <streamtuner.h>
 #include <string.h>
 #include <stdlib.h>
-#include "gettext.h"
+#include <glib/gi18n-lib.h>
+#include "streamtuner.h"
 #include "art/shoutcast.h"
 
 #define STREAMS_PER_PAGE		100
