@@ -1,5 +1,5 @@
 /*
- * $Id: sg-dumper.c,v 1.12 2004/03/21 02:55:38 jylefort Exp $
+ * $Id: sg-dumper.c,v 1.12.2.1 2004/05/11 10:54:34 jylefort Exp $
  *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -31,12 +31,13 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include <glib.h>
+#include "config.h"
 #include <stdarg.h>
 #include <stdio.h>
 #include <unistd.h>
 #include <errno.h>
-#include "gettext.h"
+#include <glib.h>
+#include <glib/gi18n-lib.h>
 #include "sg-dumper.h"
 
 /*** function declarations ***************************************************/
