@@ -1,5 +1,5 @@
 /*
- * $Id: sg-parser.c,v 1.15 2004/03/21 02:55:38 jylefort Exp $
+ * $Id: sg-parser.c,v 1.15.2.1 2004/05/11 10:54:34 jylefort Exp $
  *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -31,11 +31,11 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include <glib.h>
-#include <glib-object.h>
+#include "config.h"
 #include <stdarg.h>
 #include <string.h>
-#include "gettext.h"
+#include <glib-object.h>
+#include <glib/gi18n-lib.h>
 #include "sg-parser.h"
 #include "sg-stack.h"
 
