@@ -1,5 +1,5 @@
 /*
- * $Id: sgtk-auth-dialog.c,v 1.24 2004/03/08 05:48:20 jylefort Exp $
+ * $Id: sgtk-auth-dialog.c,v 1.24.2.1 2004/05/11 10:54:34 jylefort Exp $
  *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -31,11 +31,12 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
+#include "config.h"
+#include <glib/gi18n-lib.h>
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
 #include <stdarg.h>
 #include "art/auth.h"
-#include "gettext.h"
 #include "sgtk-auth-dialog.h"
 #include "sgtk-hig.h"
 
