@@ -1,5 +1,5 @@
 /*
- * $Id: sgtk-util.c,v 1.14 2004/03/11 17:55:04 jylefort Exp $
+ * $Id: sgtk-util.c,v 1.14.2.1 2004/05/11 10:54:34 jylefort Exp $
  *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -31,8 +31,9 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
+#include "config.h"
+#include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
-#include "gettext.h"
 
 /*** function declarations ***************************************************/
 
