@@ -1,5 +1,5 @@
 /*
- * $Id: st-about-dialog.c,v 1.33 2004/03/19 20:20:13 jylefort Exp $
+ * $Id: st-about-dialog.c,v 1.33.2.1 2004/05/11 10:54:34 jylefort Exp $
  *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -32,8 +32,8 @@
  */
 
 #include "config.h"
+#include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
-#include "gettext.h"
 #include "sgtk-dialog.h"
 #include "sgtk-hig.h"
 #include "st-about-dialog.h"
