@@ -1,5 +1,5 @@
 /*
- * $Id: st-action.c,v 1.12 2004/03/23 22:09:48 jylefort Exp $
+ * $Id: st-action.c,v 1.12.2.1 2004/05/11 10:54:34 jylefort Exp $
  *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -31,8 +31,9 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
+#include "config.h"
 #include <glib.h>
-#include "gettext.h"
+#include <glib/gi18n-lib.h>
 #include "sg-util.h"
 #include "st-thread.h"
 #include "st-action.h"
