@@ -1,5 +1,5 @@
 /*
- * $Id: st-bookmarks.c,v 1.30 2004/03/30 17:14:08 jylefort Exp $
+ * $Id: st-bookmarks.c,v 1.30.2.1 2004/05/11 10:54:34 jylefort Exp $
  *
  * Copyright (c) 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -31,9 +31,10 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
+#include "config.h"
+#include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
 #include "art/bookmarks.h"
-#include "gettext.h"
 #include "sg-util.h"
 #include "sgtk-util.h"
 #include "st-handler.h"
