@@ -1,5 +1,5 @@
 /*
- * $Id: st-browser-tab-label.c,v 1.8 2004/03/24 21:04:09 jylefort Exp $
+ * $Id: st-browser-tab-label.c,v 1.8.2.1 2004/05/11 10:54:34 jylefort Exp $
  *
  * Copyright (c) 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -31,8 +31,9 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
+#include "config.h"
+#include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
-#include "gettext.h"
 #include "sgtk-blinking-image.h"
 #include "sgtk-hig.h"
 #include "sgtk-util.h"
