@@ -1,5 +1,5 @@
 /*
- * $Id: st-browser-tab.c,v 1.141 2004/03/27 21:54:23 jylefort Exp $
+ * $Id: st-browser-tab.c,v 1.141.2.1 2004/05/11 10:54:34 jylefort Exp $
  *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -31,9 +31,10 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
+#include "config.h"
 #include <string.h>
+#include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
-#include "gettext.h"
 #include "sgtk-util.h"
 #include "sg-util.h"
 #include "st-browser-tab.h"
