@@ -1,5 +1,5 @@
 /*
- * $Id: st-cache-save.c,v 1.46 2004/03/27 01:23:05 jylefort Exp $
+ * $Id: st-cache-save.c,v 1.46.2.1 2004/05/11 10:54:35 jylefort Exp $
  *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -31,11 +31,12 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
+#include "config.h"
 #include <string.h>
 #include <unistd.h>
 #include <errno.h>
+#include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
-#include "gettext.h"
 #include "sg-dumper.h"
 #include "st-handler.h"
 #include "st-handlers.h"
