@@ -1,5 +1,5 @@
 /*
- * $Id: st-category-view.c,v 1.68 2004/03/15 18:37:09 jylefort Exp $
+ * $Id: st-category-view.c,v 1.68.2.1 2004/05/11 10:54:35 jylefort Exp $
  *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -31,9 +31,10 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include <gtk/gtk.h>
+#include "config.h"
 #include <string.h>
-#include "gettext.h"
+#include <glib/gi18n-lib.h>
+#include <gtk/gtk.h>
 #include "sg-util.h"
 #include "sgtk-handlers.h"
 #include "st-category-view.h"
