@@ -1,5 +1,5 @@
 /*
- * $Id: st-config-load.c,v 1.35 2004/03/11 19:18:17 jylefort Exp $
+ * $Id: st-config-load.c,v 1.35.2.1 2004/05/11 10:54:35 jylefort Exp $
  *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -31,11 +31,11 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include <glib.h>
-#include <glib-object.h>
+#include "config.h"
 #include <string.h>
 #include <stdlib.h>
-#include "gettext.h"
+#include <glib/gi18n-lib.h>
+#include <glib-object.h>
 #include "sg-parser.h"
 #include "st-handler.h"
 #include "st-handler-field.h"
