@@ -1,5 +1,5 @@
 /*
- * $Id: st-handler.c,v 1.124 2004/03/27 21:25:03 jylefort Exp $
+ * $Id: st-handler.c,v 1.124.2.1 2004/05/11 10:54:35 jylefort Exp $
  *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -31,9 +31,10 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include <gtk/gtk.h>
+#include "config.h"
 #include <string.h>
-#include "gettext.h"
+#include <glib/gi18n-lib.h>
+#include <gtk/gtk.h>
 #include "st-category-bag.h"
 #include "st-handler.h"
 #include "st-handler-field.h"
