@@ -1,5 +1,5 @@
 /*
- * $Id: st-handlers.c,v 1.20 2004/03/27 11:41:01 jylefort Exp $
+ * $Id: st-handlers.c,v 1.20.2.1 2004/05/11 10:54:35 jylefort Exp $
  *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -32,7 +32,7 @@
  */
 
 #include "config.h"
-#include "gettext.h"
+#include <glib/gi18n-lib.h>
 #include "sg-util.h"
 #include "st-plugin.h"
 #include "st-dialog-api.h"
