@@ -1,5 +1,5 @@
 /*
- * $Id: st-link.c,v 1.11 2004/03/21 20:58:18 jylefort Exp $
+ * $Id: st-link.c,v 1.11.2.1 2004/05/11 10:54:35 jylefort Exp $
  *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -31,7 +31,8 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include "gettext.h"
+#include "config.h"
+#include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
 #include "sgtk-util.h"
 #include "st-link.h"
