@@ -1,5 +1,5 @@
 /*
- * $Id: st-m3u.c,v 1.8 2004/03/12 15:19:33 jylefort Exp $
+ * $Id: st-m3u.c,v 1.8.2.1 2004/05/11 10:54:35 jylefort Exp $
  *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -31,10 +31,11 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
+#include "config.h"
 #include <stdio.h>
 #include <errno.h>
 #include <glib.h>
-#include "gettext.h"
+#include <glib/gi18n-lib.h>
 #include "sg-util.h"
 
 /*** function declarations ***************************************************/
