@@ -1,5 +1,5 @@
 /*
- * $Id: st-network-tab.c,v 1.40 2004/03/30 00:18:36 jylefort Exp $
+ * $Id: st-network-tab.c,v 1.40.2.1 2004/05/11 10:54:35 jylefort Exp $
  *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -31,8 +31,9 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
+#include "config.h"
+#include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
-#include "gettext.h"
 #include "art/network_preferences.h"
 #include "sgtk-hig.h"
 #include "sgtk-util.h"
