@@ -1,5 +1,5 @@
 /*
- * $Id: st-plugin.c,v 1.10 2004/03/27 11:41:16 jylefort Exp $
+ * $Id: st-plugin.c,v 1.10.2.1 2004/05/11 10:54:35 jylefort Exp $
  *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -33,8 +33,8 @@
 
 #include "config.h"
 #include <glib.h>
+#include <glib/gi18n-lib.h>
 #include <gmodule.h>
-#include "gettext.h"
 #include "st-plugin.h"
 #include "st-plugins.h"
 
