@@ -1,5 +1,5 @@
 /*
- * $Id: st-preferences-dialog.c,v 1.22 2004/03/23 22:02:29 jylefort Exp $
+ * $Id: st-preferences-dialog.c,v 1.22.2.1 2004/05/11 10:54:35 jylefort Exp $
  *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -32,8 +32,8 @@
  */
 
 #include "config.h"
+#include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
-#include "gettext.h"
 #include "sgtk-hig.h"
 #include "st-preferences-dialog.h"
 #include "st-general-tab.h"
