@@ -1,5 +1,5 @@
 /*
- * $Id: st-search-dialog.c,v 1.13 2004/03/19 11:00:38 jylefort Exp $
+ * $Id: st-search-dialog.c,v 1.13.2.1 2004/05/11 10:54:35 jylefort Exp $
  *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -31,8 +31,9 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
+#include "config.h"
+#include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
-#include "gettext.h"
 #include "sgtk-hig.h"
 #include "st-search-dialog.h"
 #include "st-stock.h"
