@@ -1,5 +1,5 @@
 /*
- * $Id: st-session.c,v 1.18 2004/03/26 19:02:43 jylefort Exp $
+ * $Id: st-session.c,v 1.18.2.1 2004/05/11 10:54:35 jylefort Exp $
  *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -31,13 +31,14 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
+#include "config.h"
 #include <errno.h>
 #include <glib.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
+#include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
-#include "gettext.h"
 #include "sg-util.h"
 #include "st-cache-load.h"
 #include "st-cache-save.h"
