@@ -1,5 +1,5 @@
 /*
- * $Id: st-settings.c,v 1.27 2004/03/26 19:02:43 jylefort Exp $
+ * $Id: st-settings.c,v 1.27.2.1 2004/05/11 10:54:35 jylefort Exp $
  *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -31,9 +31,10 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
+#include "config.h"
 #include <stdlib.h>
 #include <glib.h>
-#include "gettext.h"
+#include <glib/gi18n-lib.h>
 #include "st-dialog-api.h"
 #include "st-settings.h"
 #include "st-transfer.h"
