@@ -1,5 +1,5 @@
 /*
- * $Id: st-shell.c,v 1.170 2004/03/30 12:15:09 jylefort Exp $
+ * $Id: st-shell.c,v 1.170.2.2 2004/05/11 10:54:35 jylefort Exp $
  *
  * Copyright (c) 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -32,10 +32,10 @@
  */
 
 #include "config.h"
+#include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include "art/streamtuner.h"
-#include "gettext.h"
 #include "sg-util.h"
 #include "sgtk-hig.h"
 #include "sgtk-util.h"
@@ -1016,19 +1016,16 @@ st_shell_tab_label_drag_begin_h (GtkWidget *widget,
 				 GdkDragContext *drag_context,
 				 gpointer user_data)
 {
-  if (! gdk_pointer_is_grabbed())
-    {
-      STShell *shell = user_data;
-      GdkCursor *cursor = gdk_cursor_new(GDK_FLEUR);
+  STShell *shell = user_data;
+  GdkCursor *cursor = gdk_cursor_new(GDK_FLEUR);
 
-      gdk_pointer_grab(shell->priv->notebook->window,
-		       FALSE,
-		       GDK_BUTTON1_MOTION_MASK | GDK_BUTTON_RELEASE_MASK,
-		       NULL,
-		       cursor,
-		       drag_context->start_time);
-      gdk_cursor_unref(cursor);
-    }
+  gdk_pointer_grab(shell->priv->notebook->window,
+		   FALSE,
+		   GDK_BUTTON1_MOTION_MASK | GDK_BUTTON_RELEASE_MASK,
+		   NULL,
+		   cursor,
+		   drag_context->start_time);
+  gdk_cursor_unref(cursor);
 }
 
 static void
