@@ -1,5 +1,5 @@
 /*
- * $Id: st-stock.c,v 1.35 2004/03/24 16:34:06 jylefort Exp $
+ * $Id: st-stock.c,v 1.35.2.1 2004/05/11 10:54:35 jylefort Exp $
  *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -31,9 +31,10 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
+#include "config.h"
+#include <glib/gi18n-lib.h>
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
-#include "gettext.h"
 #include "art/add_bookmark.h"
 #include "art/tune_in.h"
 #include "art/record.h"
