@@ -1,5 +1,5 @@
 /*
- * $Id: st-stream-properties-dialog.c,v 1.86 2004/03/28 17:12:02 jylefort Exp $
+ * $Id: st-stream-properties-dialog.c,v 1.86.2.1 2004/05/11 10:54:35 jylefort Exp $
  *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -31,9 +31,10 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include <gtk/gtk.h>
+#include "config.h"
 #include <string.h>
-#include "gettext.h"
+#include <glib/gi18n-lib.h>
+#include <gtk/gtk.h>
 #include "sg-util.h"
 #include "st-stream-properties-dialog.h"
 #include "st-handler.h"
