@@ -1,5 +1,5 @@
 /*
- * $Id: st-stream-view.c,v 1.132 2004/03/19 20:00:21 jylefort Exp $
+ * $Id: st-stream-view.c,v 1.132.2.1 2004/05/11 10:54:35 jylefort Exp $
  *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -31,9 +31,10 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
+#include "config.h"
 #include <string.h>
+#include <glib/gi18n-lib.h>
 #include <gdk/gdkkeysyms.h>
-#include "gettext.h"
 #include "sgtk-handlers.h"
 #include "sg-util.h"
 #include "st-handler.h"
