@@ -1,5 +1,5 @@
 /*
- * $Id: st-thread.c,v 1.33 2004/03/30 00:10:57 jylefort Exp $
+ * $Id: st-thread.c,v 1.33.2.1 2004/05/11 10:54:35 jylefort Exp $
  *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -31,10 +31,11 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
+#include "config.h"
 #include <stdlib.h>
 #include <stdarg.h>
 #include <glib.h>
-#include "gettext.h"
+#include <glib/gi18n-lib.h>
 #include "st-dialog-api.h"
 #include "st-thread.h"
 #include "st-handler.h"
