@@ -1,5 +1,5 @@
 /*
- * $Id: st-transfer.c,v 1.73 2004/03/26 18:04:57 jylefort Exp $
+ * $Id: st-transfer.c,v 1.73.2.1 2004/05/11 10:54:35 jylefort Exp $
  *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -31,10 +31,11 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include <curl/curl.h>
-#include <gtk/gtk.h>
+#include "config.h"
 #include <string.h>
-#include "gettext.h"
+#include <curl/curl.h>
+#include <glib/gi18n-lib.h>
+#include <gtk/gtk.h>
 #include "sg-util.h"
 #include "sgtk-auth-dialog.h"
 #include "st-dialog-api.h"
